@@ -1,8 +1,14 @@
-import requests
 import base64
-from django.conf import settings
-from django.http.response import HttpResponseGone
 import logging
+import json
+
+import requests
+from pprint import pformat
+from django.conf import settings
+from django.utils.translation import ugettext as _
+
+
+default_facet_mode = getattr(settings, "STUDIOGDO_FACET_MODE", "dom5")
 
 
 class StudiogdoApi(object):
@@ -19,10 +25,8 @@ class StudiogdoApi(object):
 
     def __init__(self, root_address=DEFAULT_ROOT, options=None, cookies=None):
         self.root_address = root_address
-        if hasattr(settings, 'STUDIOGDO_OPTIONS'):
-            self.options = settings.STUDIOGDO_OPTIONS
-        else:
-            self.options = {}
+
+        self.options = getattr(settings, 'STUDIOGDO_OPTIONS', {})
         if options is not None:
             self.options.update(options)
         self.params = {}
@@ -38,10 +42,11 @@ class StudiogdoApi(object):
     def append_param(self, param, value):
         self.params[param] = value
 
+
     #
-    #   HTML FACET
+    # HTML FACET
     #
-    #   Path are encoded
+    # Path are encoded
     #
 
     def get_empty(self):
@@ -78,19 +83,12 @@ class StudiogdoApi(object):
 
     def apply_command(self, path, command, form_data=None):
         if path:
-            try:
-                base64.b64decode(path)
-            except TypeError:
-                param = 'p'
-            else:
-                param = 'ap'
-            finally:
-                self.append_param(param, path)
+            self.append_param("ap", path)
         self.append_param("c", command)
         return self.send('post', "apply.gdo", form_data)
 
     #
-    #   PYTHON FACET
+    # PYTHON FACET
     #
     #   Path are not encoded
     #
@@ -102,7 +100,7 @@ class StudiogdoApi(object):
             self.log.debug("path:%s, slot:%s, attrs:%s", path, slot, attrs)
 
         if path:
-            self.append_param("p", path)
+            self.append_param("ap", path)
         if tid:
             self.append_param("tid", tid)
         _list = '[%s]' % ', '.join("\'%s\'" % a for a in attrs)
@@ -117,28 +115,31 @@ class StudiogdoApi(object):
     #   PYTHON INTERFACE
     #
 
-    def send(self, method, url, data=None,
-             content_type='application/x-www-form-urlencoded;charset=UTF-8', files=None):
+    def send(self, method, url, data=None, content_type='application/x-www-form-urlencoded;charset=UTF-8', files=None):
         """ Return the studiogdo cookies, the XML result of a studiogdo call."""
 
         headers = {"content-type": content_type}
 
         request_kwargs = {'url': '%s/%s' % (self.root_address, url),
-                          'headers': headers}
+                          'headers': headers,
+                          }
 
         # multipart
         if content_type is None:
             request_kwargs = {'url': '%s/%s' % (self.root_address, url)}
 
-
         # add studiogdo cookies
         if self.cookies:
             request_kwargs['cookies'] = self.cookies
 
         # set default options in parameters
         self.params.update(self.options)
-        self.append_param("acceptNoStencil", "true" if settings.STUDIOGDO_DEBUG else "false")
-
+        if "acceptNoStencil" not in self.params:
+            self.append_param("acceptNoStencil", "true" if settings.STUDIOGDO_DEBUG else "false")
+        if "country" not in self.params:
+            country = getattr(settings, "STUDIOGDO_COUNTRY", None)
+            if country:
+                self.append_param("country", country)
         # set data in parameters
         data = data or {}
         self.params.update(data)
@@ -151,15 +152,33 @@ class StudiogdoApi(object):
 
         try:
             response = getattr(requests, method)(**request_kwargs)
-
-            # reset params for next call
-            self.params = {}
-
-            # memorize the cookie for several studiogdo calls in same request
-            if response.cookies:
-                self.cookies = response.cookies
-                self.studiogdo_cookies = response.cookies
-
-            return response
         except:
-            raise Exception("studiogdo service not available\n%s" % self.root_address)
+            raise Exception("studiogdo service not available (%s)" % request_kwargs['url'])
+
+        if not response.ok:
+            try:
+                reason = u"%s" % response.reason
+            except UnicodeDecodeError:
+                reason = u"%s - ISO-8859-1" % response.reason.decode("ISO-8859-1")
+            error = u"studiogdo error (code: %s, url: %s) : %s" % (response.status_code, request_kwargs['url'], reason)
+            params = pformat(self.params, indent=2)
+            raise Exception("\n".join([error.encode("utf8"),params]))
+        elif url == "apply.gdo" and default_facet_mode == "trans":
+            content = json.loads(response.content)
+            for k,v in content.iteritems():
+                if isinstance(v, list):
+                    content[k] = [_(vi) for vi in v]
+                elif isinstance(v, basestring) and not v.isdigit():
+                    content[k] = [_(vi) for vi in v]
+            else:
+                response._content = json.dumps(content)
+
+        # reset params for next call
+        self.params = {}
+
+        # memorize the cookie for several studiogdo calls in same request
+        if response.cookies:
+            self.cookies = response.cookies
+            self.studiogdo_cookies = response.cookies
+
+        return response
