@@ -8,25 +8,24 @@ def path(exp, skel, context=None, template_name=None):
     reg = re.compile(r'%s' % (exp,))
     if isinstance(skel, basestring):
         skel = [skel]
-    skel_dict = {'skel': skel, 'context': context, }
-    if template_name:
-        skel_dict['template_name'] = template_name
-    return (reg, skel_dict)
+    return (reg, {"skel": skel, "context": context, "template_name": template_name})
 
 
 class Patterns(object):
-
     def __init__(self, *kwargs):
         self._regexes = OrderedDict()
         for elt in kwargs:
             self._regexes[elt[0]] = elt[1]
 
     def __getitem__(self, name):
-        for regex, value in self._regexes.items():
+        # on rajoute dans le skel_dict les variables du regexp du path
+        for regex, path_dict in self._regexes.items():
             m = regex.match(name)
-            if m is not None:
-                value.update(m.groupdict())
-                return value.copy()
+            if m:
+                path_group = m.groupdict()
+                path_dict_return = path_dict.copy()
+                path_dict_return.update({"path_group": path_group})
+                return path_dict_return
         raise KeyError('Key %s does not match any regex' % name)
 
     def iterkeys(self):
@@ -38,4 +37,5 @@ class Patterns(object):
     def keys(self):
         return [reg.pattern for reg in self._regexes.iterkeys()]
 
+
 patterns = Patterns
